@@ -18,21 +18,19 @@
 # along with datastructures. If not, see <http://www.gnu.org/licenses/>.
 
 #' @import Rcpp
-.onLoad <- function(libname, pkgname)
-{
-    Rcpp::loadModule("bimap_module", TRUE)
-    Rcpp::loadModule("hashmap_module", TRUE)
-    Rcpp::loadModule("multimap_module", TRUE)
+.onLoad <- function(libname, pkgname) {
+  Rcpp::loadModule("bimap_module", TRUE)
+  Rcpp::loadModule("hashmap_module", TRUE)
+  Rcpp::loadModule("multimap_module", TRUE)
 
-    Rcpp::loadModule("binomial_heap_module", TRUE)
-    Rcpp::loadModule("fibonacci_heap_module", TRUE)
+  Rcpp::loadModule("binomial_heap_module", TRUE)
+  Rcpp::loadModule("fibonacci_heap_module", TRUE)
 
-    Rcpp::loadModule("queue_module", TRUE)
-    Rcpp::loadModule("stack_module", TRUE)
+  Rcpp::loadModule("queue_module", TRUE)
+  Rcpp::loadModule("stack_module", TRUE)
 }
 
 
-.onUnload <- function(libpath)
-{
-    library.dynam.unload("datastructures", libpath)
+.onUnload <- function(libpath) {
+  library.dynam.unload("datastructures", libpath)
 }
